A simple library for simulating and solving [polymatrix games](https://en.wikipedia.org/wiki/Succinct_game#Polymatrix_games), where players are nodes of a network and edges represent two-player games. 

# LICENSE
see LICENSE.txt
# INSTALLATION

pip install polymatrixgames

# USAGE

# ARCHITECTURE

![Polymatrix game software architecture](https://github.com/python-polymatrix-games/polymatrix-games/blob/main/corpgame%20architecture.png) "Polymatrix game software architecture")


# LITERATURE